BleConfig

Struct BleConfig 

pub struct BleConfig {
    pub adapter: Option<String>,
    pub psm: Option<u16>,
    pub mtu: Option<u16>,
    pub max_connections: Option<usize>,
    pub connect_timeout_ms: Option<u64>,
    pub advertise: Option<bool>,
    pub scan: Option<bool>,
    pub auto_connect: Option<bool>,
    pub accept_connections: Option<bool>,
    pub probe_cooldown_secs: Option<u64>,
}
BLE transport instance configuration.

BleConfig is always compiled (for config parsing on any platform), but the transport runtime requires Linux and the ble feature.

Fields

adapter: Option<String>

HCI adapter name (e.g., “hci0”). Required.

psm: Option<u16>

L2CAP PSM for FIPS connections. Default: 0x0085 (133).

mtu: Option<u16>

Default MTU for BLE connections. Default: 2048.

max_connections: Option<usize>

Maximum concurrent BLE connections. Default: 7.

connect_timeout_ms: Option<u64>

Outbound connect timeout in milliseconds. Default: 10000.

advertise: Option<bool>

Broadcast BLE advertisements. Default: true.

scan: Option<bool>

Listen for BLE advertisements. Default: true.

auto_connect: Option<bool>

Auto-connect to discovered BLE peers. Default: false.

accept_connections: Option<bool>

Accept incoming BLE connections. Default: true.

probe_cooldown_secs: Option<u64>

Probe cooldown in seconds. After probing a BLE address, wait this long before probing the same address again. Default: 30.

Implementations

Source

impl BleConfig

pub fn adapter(&self) -> &str

Get the adapter name. Default: “hci0”.

pub fn psm(&self) -> u16

Get the L2CAP PSM. Default: 0x0085.

pub fn mtu(&self) -> u16

Get the default MTU. Default: 2048.

pub fn max_connections(&self) -> usize

Get the maximum concurrent connections. Default: 7.

pub fn connect_timeout_ms(&self) -> u64

Get the connect timeout in milliseconds. Default: 10000.

pub fn advertise(&self) -> bool

Whether to broadcast advertisements. Default: true.

pub fn scan(&self) -> bool

Whether to scan for advertisements. Default: true.

pub fn auto_connect(&self) -> bool

Whether to auto-connect to discovered peers. Default: false.

pub fn accept_connections(&self) -> bool

Whether to accept incoming connections. Default: true.

pub fn probe_cooldown_secs(&self) -> u64

Get the probe cooldown in seconds. Default: 30.