pub struct LocalInstanceAdvertisement {
pub npub: String,
pub startup_epoch: [u8; 8],
pub capabilities: Vec<LocalInstanceCapability>,
}Expand description
Direct in-memory provider record learned over an authenticated local FIPS link. A changed startup epoch denotes a restarted provider even when its long-lived identity is unchanged.
Fields
npub: Stringstartup_epoch: [u8; 8]capabilities: Vec<LocalInstanceCapability>Implementations
Sourceimpl LocalInstanceAdvertisement
impl LocalInstanceAdvertisement
Sourcepub fn capability(&self, name: &str) -> Option<&LocalInstanceCapability>
pub fn capability(&self, name: &str) -> Option<&LocalInstanceCapability>
Return this provider’s preferred advert for one capability name.