pub struct FipsEndpointBulkDataBuilder(/* private fields */);Expand description
Builder for one EndpointDataBulk body from borrowed packet slices.
Implementations
Sourceimpl FipsEndpointBulkDataBuilder
impl FipsEndpointBulkDataBuilder
Sourcepub fn packet_count(&self) -> usize
pub fn packet_count(&self) -> usize
Number of endpoint packets currently encoded.
Sourcepub fn packet_bytes(&self) -> usize
pub fn packet_bytes(&self) -> usize
Sum of packet payload bytes currently encoded.
Sourcepub fn can_push_packet(&self, packet: &[u8]) -> bool
pub fn can_push_packet(&self, packet: &[u8]) -> bool
Whether packet fits in this body without exceeding FSP bulk limits.
Sourcepub fn push_packet(&mut self, packet: &[u8]) -> bool
pub fn push_packet(&mut self, packet: &[u8]) -> bool
Append one packet to this body.
Sourcepub fn finish(self) -> Option<FipsEndpointBulkData>
pub fn finish(self) -> Option<FipsEndpointBulkData>
Finish the body, returning None if no packets were added.