pub struct FipsEndpointRelayStatus {
pub url: String,
pub status: String,
}Expand description
Live Nostr relay state visible to an embedded application.
Fields
url: Stringstatus: StringTrait Implementations
Sourceimpl Clone for FipsEndpointRelayStatus
impl Clone for FipsEndpointRelayStatus
Sourcefn clone(&self) -> FipsEndpointRelayStatus
fn clone(&self) -> FipsEndpointRelayStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FipsEndpointRelayStatus
impl Debug for FipsEndpointRelayStatus
Sourceimpl PartialEq for FipsEndpointRelayStatus
impl PartialEq for FipsEndpointRelayStatus
Sourcefn eq(&self, other: &FipsEndpointRelayStatus) -> bool
fn eq(&self, other: &FipsEndpointRelayStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FipsEndpointRelayStatus
impl StructuralPartialEq for FipsEndpointRelayStatus