pub struct GatewayControlSocket { /* private fields */ }Expand description
Gateway control socket listener.
Implementations
Sourceimpl GatewayControlSocket
impl GatewayControlSocket
Sourcepub fn bind() -> Result<Self, Error>
pub fn bind() -> Result<Self, Error>
Bind the gateway control socket.
Creates parent directories if needed, removes stale socket files,
and sets root:fips 0770 permissions.
Sourcepub async fn accept_loop(self, snapshot_rx: Receiver<Option<GatewaySnapshot>>)
pub async fn accept_loop(self, snapshot_rx: Receiver<Option<GatewaySnapshot>>)
Run the accept loop, reading the latest snapshot from the watch channel.