Module dns

Module dns 

Gateway DNS resolver.

Forwarding proxy that handles .fips queries from LAN hosts, forwards them to the FIPS daemon resolver (localhost:5354), and returns virtual IP addresses from the pool.

The daemon resolver populates its identity cache as a side effect of resolution, which is required for fips0 routing to work.

Structs

DnsAllocation
Events emitted by the DNS resolver.

Functions

run_dns_resolver
Run the gateway DNS resolver.