pub struct FipsEndpointDirectPacketRunMeta { /* private fields */ }Expand description
Authenticated source/session facts for a direct endpoint packet run.
Implementations
Sourceimpl FipsEndpointDirectPacketRunMeta
impl FipsEndpointDirectPacketRunMeta
Sourcepub fn source_peer(&self) -> &PeerIdentity
pub fn source_peer(&self) -> &PeerIdentity
Authenticated FIPS peer that originated every packet in this run.
Sourcepub fn source_node_addr(&self) -> &NodeAddr
pub fn source_node_addr(&self) -> &NodeAddr
FIPS node address that originated every packet in this run.
Sourcepub fn source_npub(&self) -> String
pub fn source_npub(&self) -> String
Source Nostr public key as human-facing bech32 text.
Sourcepub fn previous_hop_node_addr(&self) -> &NodeAddr
pub fn previous_hop_node_addr(&self) -> &NodeAddr
Authenticated previous hop for this established FSP receive run.
Sourcepub fn is_direct_path(&self) -> bool
pub fn is_direct_path(&self) -> bool
Whether FIPS received the run directly from the source node.
Sourcepub fn received_k_bit(&self) -> bool
pub fn received_k_bit(&self) -> bool
Whether the established FSP packet carried the key-epoch bit.
Sourcepub fn enqueued_at_ms(&self) -> u64
pub fn enqueued_at_ms(&self) -> u64
Unix-millisecond time when FIPS handed this run to the direct sink.