pub struct FipsEndpointDirectSourceRun { /* private fields */ }Expand description
Consecutive direct endpoint packets from one authenticated FIPS source.
Implementations
Sourceimpl FipsEndpointDirectSourceRun
impl FipsEndpointDirectSourceRun
Sourcepub fn source_peer(&self) -> &PeerIdentity
pub fn source_peer(&self) -> &PeerIdentity
Authenticated FIPS peer that originated every packet in this run.
Sourcepub fn source_node_addr(&self) -> &NodeAddr
pub fn source_node_addr(&self) -> &NodeAddr
FIPS node address that originated every packet in this run.
Sourcepub fn source_npub(&self) -> String
pub fn source_npub(&self) -> String
Source Nostr public key as human-facing bech32 text.
Sourcepub fn enqueued_at_ms(&self) -> u64
pub fn enqueued_at_ms(&self) -> u64
Unix-millisecond time when FIPS handed this run to the direct sink.
Sourcepub fn packets(&self) -> &[PacketBuffer]
pub fn packets(&self) -> &[PacketBuffer]
Packets delivered for this source run.
Sourcepub fn into_parts(self) -> (PeerIdentity, Vec<PacketBuffer>)
pub fn into_parts(self) -> (PeerIdentity, Vec<PacketBuffer>)
Take ownership of the run source and packets.
Sourcepub fn into_packets(self) -> Vec<PacketBuffer>
pub fn into_packets(self) -> Vec<PacketBuffer>
Take ownership of the delivered packets.