pub enum ReplayRejection {
Duplicate,
TooOld,
}Expand description
Reason a counter is rejected by the replay window.
Variants
Duplicate
Counter is inside the replay window but its bit was already observed.
TooOld
Counter is behind the retained replay window.