ConnectivityState

Enum ConnectivityState 

pub enum ConnectivityState {
    Connected,
    Stale,
    Reconnecting,
    Disconnected,
}
Connectivity state for an active peer.

This is simpler than the full PeerState since authentication is complete.

Variants



Connected

Peer is fully connected and responsive.



Stale

Peer hasn’t been heard from recently (potential timeout).



Reconnecting

Connection lost, attempting to reconnect.



Disconnected

Peer has been explicitly disconnected.

Implementations

Source

impl ConnectivityState

pub fn can_send(&self) -> bool

Check if the peer is usable for sending traffic.

pub fn is_terminal(&self) -> bool

Check if this is a terminal state requiring cleanup.

pub fn is_healthy(&self) -> bool

Check if peer is fully healthy.