PromotionResult

Enum PromotionResult 

pub enum PromotionResult {
    Promoted(NodeAddr),
    CrossConnectionLost {
        winner_link_id: LinkId,
    },
    CrossConnectionWon {
        loser_link_id: LinkId,
        node_addr: NodeAddr,
    },
}
Result of attempting to promote a connection to active peer.

When a handshake completes, we may discover that we already have a connection to this peer (cross-connection). The tie-breaker rule determines which connection survives.

Note: Returns NodeAddr instead of ActivePeer because ActivePeer cannot be cloned (it contains NoiseSession which has cryptographic state). Callers can look up the peer from the peers map using the NodeAddr.

Variants



Promoted(NodeAddr)

New peer created successfully.



CrossConnectionLost

Cross-connection detected. This connection lost the tie-breaker and should be closed.

Fields

winner_link_id: LinkId

The link that won (existing connection).



CrossConnectionWon

Cross-connection detected. This connection won the tie-breaker. The existing connection was replaced.

Fields

loser_link_id: LinkId

The link that lost (previous connection, now closed).

node_addr: NodeAddr

The node ID of the peer.

Implementations

Source

impl PromotionResult

pub fn node_addr(&self) -> Option<NodeAddr>

Get the node ID if promotion succeeded.

pub fn should_close_this_connection(&self) -> bool

Check if this connection should be closed.

Get the link that should be closed, if any.