pub enum TransportError {
}Expand description
Errors related to transport operations.
Variants
NotStarted
AlreadyStarted
StartFailed(String)
ShutdownFailed(String)
LinkFailed(String)
SendFailed(String)
RecvFailed(String)
InvalidAddress(String)
MtuExceeded
Timeout
ConnectionRefused
NotSupported(String)
Io(Error)
Implementations
Sourceimpl TransportError
impl TransportError
True when the local OS says the outbound underlay path is temporarily unsendable, rather than the peer or protocol being bad.