Module control

Module control 

Tor control port client.

Minimal async client for the Tor control protocol (control-spec). Implements AUTHENTICATE and GETINFO for monitoring the Tor daemon.

Structs

TorControlClient
Async Tor control port client.
TorMonitoringInfo
Snapshot of Tor daemon status collected via control port GETINFO queries.

Enums

ControlAuth
Control port authentication method.
TorControlError
Errors from the Tor control port client.