pub fn file_mtime(path: &Path) -> Option<SystemTime>Expand description
Return the modification time of a file, or None if it doesn’t exist or
the metadata can’t be read.
pub fn file_mtime(path: &Path) -> Option<SystemTime>Return the modification time of a file, or None if it doesn’t exist or
the metadata can’t be read.