SessionConfig

Struct SessionConfig 

pub struct SessionConfig {
    pub default_ttl: u8,
    pub pending_packets_per_dest: usize,
    pub pending_max_destinations: usize,
    pub idle_timeout_secs: u64,
    pub coords_warmup_packets: u8,
    pub coords_response_interval_ms: u64,
}
Session/data plane (node.session.*).

Fields

default_ttl: u8

Default SessionDatagram TTL (node.session.default_ttl).

pending_packets_per_dest: usize

Queue depth per dest during session establishment (node.session.pending_packets_per_dest).

pending_max_destinations: usize

Max destinations with pending packets (node.session.pending_max_destinations).

idle_timeout_secs: u64

Idle session timeout in seconds (node.session.idle_timeout_secs). Established sessions with no application data for this duration are removed. MMP reports do not count as activity for this timer.

coords_warmup_packets: u8

Number of initial data packets per session that include COORDS_PRESENT for transit cache warmup (node.session.coords_warmup_packets). Also used as the reset count on CoordsRequired receipt.

coords_response_interval_ms: u64

Minimum interval (ms) between standalone CoordsWarmup responses to CoordsRequired/PathBroken signals, per destination (node.session.coords_response_interval_ms).