pub struct EstablishedTraversal {
pub session_id: String,
pub peer_npub: String,
pub remote_addr: SocketAddr,
pub socket: UdpSocket,
pub transport_name: Option<String>,
pub transport_config: Option<UdpConfig>,
}Expand description
Established UDP traversal ready to be handed into FIPS.
The socket must already be bound and must be the same socket used for the traversal runtime’s STUN and punch traffic so the NAT mapping is preserved.
Fields
session_id: StringRendezvous session identifier for logging/correlation.
peer_npub: StringRemote peer identity in npub form.
remote_addr: SocketAddrThe selected remote UDP endpoint to use for the FIPS handshake.
socket: UdpSocketThe live UDP socket carrying the established mapping.
transport_name: Option<String>Optional name for the adopted UDP transport.
transport_config: Option<UdpConfig>Optional UDP transport tuning overrides.
Implementations
Sourceimpl EstablishedTraversal
impl EstablishedTraversal
Sourcepub fn new(
session_id: impl Into<String>,
peer_npub: impl Into<String>,
remote_addr: SocketAddr,
socket: UdpSocket,
) -> Self
pub fn new( session_id: impl Into<String>, peer_npub: impl Into<String>, remote_addr: SocketAddr, socket: UdpSocket, ) -> Self
Construct an established traversal handoff.
Sourcepub fn with_transport_name(self, name: impl Into<String>) -> Self
pub fn with_transport_name(self, name: impl Into<String>) -> Self
Attach an explicit transport name to the adopted UDP transport.
Sourcepub fn with_transport_config(self, config: UdpConfig) -> Self
pub fn with_transport_config(self, config: UdpConfig) -> Self
Override UDP transport tuning for the adopted socket.