NodeDeliveredPacket

Struct NodeDeliveredPacket 

pub struct NodeDeliveredPacket {
    pub source_node_addr: NodeAddr,
    pub source_npub: Option<String>,
    pub destination: FipsAddress,
    pub packet: Vec<u8>,
}
Source-attributed packet delivered by a node running without a system TUN.

Fields

source_node_addr: NodeAddr

FIPS node address that originated the packet.

source_npub: Option<String>

Source Nostr public key when the node has learned it.

destination: FipsAddress

Destination FIPS address from the IPv6 packet.

packet: Vec<u8>

Full IPv6 packet after FIPS session decapsulation.