pub struct ConnectionPool<S> { /* private fields */ }Expand description
Connection pool managing BLE connections with priority eviction.
Implementations
Sourceimpl<S> ConnectionPool<S>
impl<S> ConnectionPool<S>
Sourcepub fn max_connections(&self) -> usize
pub fn max_connections(&self) -> usize
Get the maximum pool capacity.
Sourcepub fn get(&self, addr: &TransportAddr) -> Option<&BleConnection<S>>
pub fn get(&self, addr: &TransportAddr) -> Option<&BleConnection<S>>
Look up a connection by transport address.
Sourcepub fn get_mut(&mut self, addr: &TransportAddr) -> Option<&mut BleConnection<S>>
pub fn get_mut(&mut self, addr: &TransportAddr) -> Option<&mut BleConnection<S>>
Look up a mutable connection by transport address.
Sourcepub fn contains(&self, addr: &TransportAddr) -> bool
pub fn contains(&self, addr: &TransportAddr) -> bool
Check if a connection exists for the given address.
Sourcepub fn insert(
&mut self,
addr: TransportAddr,
conn: BleConnection<S>,
) -> Result<Option<TransportAddr>, TransportError>
pub fn insert( &mut self, addr: TransportAddr, conn: BleConnection<S>, ) -> Result<Option<TransportAddr>, TransportError>
Try to insert a connection, evicting if necessary.
Returns Ok(evicted_addr) on success (with optional evicted peer),
or Err if the pool is full and the new connection cannot evict anyone.
Sourcepub fn remove(&mut self, addr: &TransportAddr) -> Option<BleConnection<S>>
pub fn remove(&mut self, addr: &TransportAddr) -> Option<BleConnection<S>>
Remove a connection by address.
Sourcepub fn addrs(&self) -> Vec<TransportAddr>
pub fn addrs(&self) -> Vec<TransportAddr>
Get all connection addresses.