pub struct ParentDeclaration { /* private fields */ }Expand description
A node’s declaration of its parent in the spanning tree.
Each node periodically announces its parent selection. The declaration
includes a monotonic sequence number for freshness and a signature
for authenticity. When parent_id == node_addr, the node declares itself
as a root candidate.
Implementations
Sourceimpl ParentDeclaration
impl ParentDeclaration
Sourcepub fn new(
node_addr: NodeAddr,
parent_id: NodeAddr,
sequence: u64,
timestamp: u64,
) -> Self
pub fn new( node_addr: NodeAddr, parent_id: NodeAddr, sequence: u64, timestamp: u64, ) -> Self
Create a new unsigned parent declaration.
The declaration must be signed before transmission using set_signature().
Sourcepub fn self_root(node_addr: NodeAddr, sequence: u64, timestamp: u64) -> Self
pub fn self_root(node_addr: NodeAddr, sequence: u64, timestamp: u64) -> Self
Create a self-declaration (node is root candidate).
Sourcepub fn with_signature(
node_addr: NodeAddr,
parent_id: NodeAddr,
sequence: u64,
timestamp: u64,
signature: Signature,
) -> Self
pub fn with_signature( node_addr: NodeAddr, parent_id: NodeAddr, sequence: u64, timestamp: u64, signature: Signature, ) -> Self
Create a declaration with a pre-computed signature.
Sourcepub fn set_signature(&mut self, signature: Signature)
pub fn set_signature(&mut self, signature: Signature)
Set the signature after signing.
Sourcepub fn sign(&mut self, identity: &Identity) -> Result<(), TreeError>
pub fn sign(&mut self, identity: &Identity) -> Result<(), TreeError>
Sign this declaration with the given identity.
The identity’s node_addr must match this declaration’s node_addr. Returns an error if the node_addrs don’t match.
Sourcepub fn signing_bytes(&self) -> Vec<u8> ⓘ
pub fn signing_bytes(&self) -> Vec<u8> ⓘ
Get the bytes that should be signed.
Format: node_addr (16) || parent_id (16) || sequence (8) || timestamp (8)
Sourcepub fn verify(&self, pubkey: &XOnlyPublicKey) -> Result<(), TreeError>
pub fn verify(&self, pubkey: &XOnlyPublicKey) -> Result<(), TreeError>
Verify the signature on this declaration.
Returns Ok(()) if the signature is valid, or an error otherwise.
Sourcepub fn is_fresher_than(&self, other: &ParentDeclaration) -> bool
pub fn is_fresher_than(&self, other: &ParentDeclaration) -> bool
Check if this declaration is fresher than another.